@@ -1,7 +1,12 @@
 import getpass
 import ConfigParser
 import json
+import requests
+import sys
+import urlparse
 from os.path import join, expanduser
+from os import getenv
+import docker
 
 from tutum.api import auth
 from tutum.api import exceptions
@@ -15,6 +20,11 @@ AUTH_SECTION = 'auth'
 USER_OPTION = "user"
 APIKEY_OPTION = 'apikey'
 
+TUTUM_AUTH_ERROR_EXIT_CODE = 2
+TUTUM_REGISTER_ERROR_EXIT_CODE = 3
+EXCEPTION_EXIT_CODE = 4
+DOCKER_NOT_RUNNING_EXIT_CODE = 5
+
 
 def authenticate():
 
@@ -32,8 +42,60 @@ def authenticate():
             print "Login succeeded!"
     except exceptions.TutumAuthError:
         print "Wrong username and/or password. Please try to login again"
+        sys.exit(TUTUM_AUTH_ERROR_EXIT_CODE)
     except Exception as e:
         print e
+        sys.exit(EXCEPTION_EXIT_CODE)
+
+
+def register():
+    import tutum_cli
+
+    username = raw_input("Username: ")
+    password1 = 0
+    password2 = 1
+    while password1 != password2:
+        password1 = getpass.getpass()
+        password2 = getpass.getpass(prompt="Repeat your password: ")
+        if password1 != password2:
+            print "Your passwords do not match, please try again"
+        else:
+            break
+    email = raw_input("Email: ")
+
+    headers = {"Content-Type": "application/json", "User-Agent": "tutum/%s" % tutum_cli.VERSION}
+    data = {'username': username, "password1": password1, "password2": password2, "email": email}
+
+    r = requests.post(urlparse.urljoin(tutum.base_url, "register/"), data=json.dumps(data), headers=headers)
+
+    if r.status_code == 201:
+        print "Account created. Please check your email for activation instructions."
+
+    else:
+        print r.json()
+        sys.exit(TUTUM_REGISTER_ERROR_EXIT_CODE)
+
+
+def search(text):
+    try:
+        docker_client = docker.Client(base_url=getenv("DOCKER_HOST"))
+        results = docker_client.search(text)
+        headers = ["NAME", "DESCRIPTION", "STARS", "OFFICIAL", "TRUSTED"]
+        data_list = []
+        if len(results) != 0:
+            for result in results:
+                description = result["description"].replace("\n", "\\n")
+                description = description[:80] + " [...]" if len(result["description"]) > 80 else description
+                data_list.append([result["name"], description
+                                  , str(result["star_count"]),
+                                  u"\u2713" if result["is_official"] else "",
+                                  u"\u2713" if result["is_trusted"] else ""])
+        else:
+            data_list.append(["", "", "", "", ""])
+        utils.tabulate_result(data_list, headers)
+    except Exception:
+        print "Cannot connect to docker (is it running?)"
+        sys.exit(DOCKER_NOT_RUNNING_EXIT_CODE)
 
 
 def apps(quiet=False, status=None):
@@ -58,55 +120,56 @@ def apps(quiet=False, status=None):
             utils.tabulate_result(data_list, headers)
     except Exception as e:
         print e
+        sys.exit(EXCEPTION_EXIT_CODE)
 
 
-def application_details(identifiers):
+def details(identifiers):
     for identifier in identifiers:
         try:
-            app_details = utils.fetch_app(identifier)
-            print json.dumps(app_details.get_all_attributes(), indent=2)
+            app_or_container = utils.launch_queries_in_parallel(identifier)
+            print json.dumps(app_or_container.get_all_attributes(), indent=2)
         except Exception as e:
             print e
 
 
-def app_start(identifiers):
+def start(identifiers):
     for identifier in identifiers:
         try:
-            app_details = utils.fetch_app(identifier)
-            result = app_details.start()
+            app_or_container = utils.launch_queries_in_parallel(identifier)
+            result = app_or_container.start()
             if result:
-                print app_details.uuid
+                print app_or_container.uuid
         except Exception as e:
             print e
 
 
-def app_stop(identifiers):
+def stop(identifiers):
     for identifier in identifiers:
         try:
-            app_details = utils.fetch_app(identifier)
-            result = app_details.stop()
+            app_or_container = utils.launch_queries_in_parallel(identifier)
+            result = app_or_container.stop()
             if result:
-                print app_details.uuid
+                print app_or_container.uuid
         except Exception as e:
             print e
 
 
-def app_terminate(identifiers):
+def terminate(identifiers):
     for identifier in identifiers:
         try:
-            app_details = utils.fetch_app(identifier)
-            result = app_details.delete()
+            app_or_container = utils.launch_queries_in_parallel(identifier)
+            result = app_or_container.delete()
             if result:
-                print app_details.uuid
+                print app_or_container.uuid
         except Exception as e:
             print e
 
 
-def app_logs(identifiers):
+def logs(identifiers):
     for identifier in identifiers:
         try:
-            app_details = utils.fetch_app(identifier)
-            print app_details.logs
+            app_or_container = utils.launch_queries_in_parallel(identifier)
+            print app_or_container.logs
         except Exception as e:
             print e
 
@@ -152,6 +215,7 @@ def app_run(image, name, container_size, target_num_containers, run_command, ent
             print app.uuid
     except Exception as e:
         print e
+        sys.exit(EXCEPTION_EXIT_CODE)
 
 
 def ps(app_identifier, quiet=False, status=None):
@@ -190,57 +254,7 @@ def ps(app_identifier, quiet=False, status=None):
             utils.tabulate_result(data_list, headers)
     except Exception as e:
         print e
-
-
-def container_inspect(identifiers):
-    for identifier in identifiers:
-        try:
-            container_details = utils.fetch_container(identifier)
-            print json.dumps(container_details.get_all_attributes(), indent=2)
-        except Exception as e:
-            print e
-
-
-def container_start(identifiers):
-    for identifier in identifiers:
-        try:
-            container_details = utils.fetch_container(identifier)
-            result = container_details.start()
-            if result:
-                print container_details.uuid
-        except Exception as e:
-            print e
-
-
-def container_stop(identifiers):
-    for identifier in identifiers:
-        try:
-            container_details = utils.fetch_container(identifier)
-            result = container_details.stop()
-            if result:
-                print container_details.uuid
-        except Exception as e:
-            print e
-
-
-def container_terminate(identifiers):
-    for identifier in identifiers:
-        try:
-            container_details = utils.fetch_container(identifier)
-            result = container_details.delete()
-            if result:
-                print container_details.uuid
-        except Exception as e:
-            print e
-
-
-def container_logs(identifiers):
-    for identifier in identifiers:
-        try:
-            container_details = utils.fetch_container(identifier)
-            print container_details.logs
-        except Exception as e:
-            print e
+        sys.exit(EXCEPTION_EXIT_CODE)
 
 
 def images(quiet=False, jumpstarts=False, linux=False):
@@ -251,7 +265,7 @@ def images(quiet=False, jumpstarts=False, linux=False):
             image_list = tutum.Image.list(base_image=True)
         else:
             image_list = tutum.Image.list(is_private_image=True)
-        headers = ["Name", "Description"]
+        headers = ["NAME", "DESCRIPTION"]
         data_list = []
         name_list = []
         if len(image_list) != 0:
@@ -268,6 +282,7 @@ def images(quiet=False, jumpstarts=False, linux=False):
             utils.tabulate_result(data_list, headers)
     except Exception as e:
         print e
+        sys.exit(EXCEPTION_EXIT_CODE)
 
 
 def add_image(repository, username, password, description):
@@ -278,6 +293,7 @@ def add_image(repository, username, password, description):
             print image.name
     except Exception as e:
         print e
+        sys.exit(EXCEPTION_EXIT_CODE)
 
 
 def remove_image(repositories):
