@@ -7,7 +7,7 @@ from tutumcli import parsers
 from tutumcli import commands
 
 
-VERSION = "0.7.1"
+VERSION = "0.7.3"
 
 sys.stdout = codecs.getwriter('utf8')(sys.stdout)
 
@@ -25,31 +25,37 @@ parent_parser = argparse.ArgumentParser(add_help=False)
 
 # Commands
 parsers.add_login_parser(subparsers, parent_parser)
-parsers.add_apps_parser(subparsers, parent_parser)
-parsers.add_containers_parser(subparsers, parent_parser)
+parsers.add_register_parser(subparsers, parent_parser)
+parsers.add_search_parser(subparsers, parent_parser)
+parsers.add_apps_and_containers_parser(subparsers, parent_parser)
 parsers.add_images_parser(subparsers, parent_parser)
 
 
 def main():
     if len(sys.argv) == 1:
         parser.print_help()
-        sys.exit(1)
+        sys.exit(0)
+
     # Parse args
     args = parser.parse_args()
     if args.command == "login":
         commands.authenticate()
+    elif args.command == "register":
+        commands.register()
+    elif args.command == "search":
+        commands.search(args.text)
     elif args.command == "apps":
         commands.apps(args.quiet, args.status)
     elif args.command == "inspect":
-        commands.application_details(args.identifier)
+        commands.details(args.identifier)
     elif args.command == "start":
-        commands.app_start(args.identifier)
+        commands.start(args.identifier)
     elif args.command == "stop":
-        commands.app_stop(args.identifier)
+        commands.stop(args.identifier)
     elif args.command == "terminate":
-        commands.app_terminate(args.identifier)
+        commands.terminate(args.identifier)
     elif args.command == "logs":
-        commands.app_logs(args.identifier)
+        commands.logs(args.identifier)
     elif args.command == "scale":
         commands.app_scale(args.identifier, args.target_num_containers)
     elif args.command == "alias":
@@ -63,16 +69,6 @@ def main():
                          autoreplace=args.autoreplace, autodestroy=args.autodestroy, roles=args.role)
     elif args.command == "ps":
             commands.ps(args.identifier, args.quiet, args.status)
-    elif args.command == "inspect-container":
-        commands.container_inspect(args.identifier)
-    elif args.command == "logs-container":
-        commands.container_logs(args.identifier)
-    elif args.command == "start-container":
-        commands.container_start(args.identifier)
-    elif args.command == "stop-container":
-        commands.container_stop(args.identifier)
-    elif args.command == "terminate-container":
-        commands.container_terminate(args.identifier)
     elif args.command == "images":
         commands.images(args.quiet, args.jumpstarts, args.linux)
     elif args.command == "add":
